controller

package
v0.0.0-...-227b0cc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 3, 2023 License: Apache-2.0 Imports: 29 Imported by: 0

Documentation

Index

Constants

const (

	// SuccessSynced is used as part of the Event 'reason' when a podScale is synced
	SuccessSynced string = "Synced"

	// MessageResourceSynced is the message used for an Event fired when a configmap
	// is synced successfully
	MessageResourceSynced string = "Community Settings synced successfully"
)

Variables

This section is empty.

Functions

func ArePodsReady

func ArePodsReady(pods []*corev1.Pod) bool

func IsPodReady

func IsPodReady(pod *corev1.Pod) bool

func NamespaceNameFunction

func NamespaceNameFunction(url *url.URL) string

format: http://../function/<namespace>/<function-name>

Types

type LoadBalancerController

type LoadBalancerController struct {
	// contains filtered or unexported fields
}

LoadBalancerController works at node level to forward an incoming request for a function to the right backend, implementing load balancing policies.

func NewController

func NewController(
	kubernetesClientset *kubernetes.Clientset,
	eaClientSet eaclientset.Interface,
	informers informers.Informers,
	node string,
) *LoadBalancerController

NewController returns a new SystemController

func (*LoadBalancerController) Run

func (c *LoadBalancerController) Run(threadiness int, stopCh <-chan struct{}) error

Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shutdown the workqueue and wait for workers to finish processing their current work items.

func (*LoadBalancerController) Shutdown

func (c *LoadBalancerController) Shutdown()

Shutdown is called when the controller has finished its work

Jump to