Documentation
¶
Index ¶
Constants ¶
const ( // SuccessSynced is used as part of the Event 'reason' when a podScale is synced SuccessSynced string = "Synced" // MessageResourceSynced is the message used for an Event fired when a configmap // is synced successfully MessageResourceSynced string = "Community Settings synced successfully" )
Variables ¶
This section is empty.
Functions ¶
func ArePodsReady ¶
func IsPodReady ¶
func NamespaceNameFunction ¶
format: http://../function/<namespace>/<function-name>
Types ¶
type LoadBalancerController ¶
type LoadBalancerController struct {
// contains filtered or unexported fields
}
LoadBalancerController works at node level to forward an incoming request for a function to the right backend, implementing load balancing policies.
func NewController ¶
func NewController( kubernetesClientset *kubernetes.Clientset, eaClientSet eaclientset.Interface, informers informers.Informers, node string, ) *LoadBalancerController
NewController returns a new SystemController
func (*LoadBalancerController) Run ¶
func (c *LoadBalancerController) Run(threadiness int, stopCh <-chan struct{}) error
Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shutdown the workqueue and wait for workers to finish processing their current work items.
func (*LoadBalancerController) Shutdown ¶
func (c *LoadBalancerController) Shutdown()
Shutdown is called when the controller has finished its work
Click to show internal directories.
Click to hide internal directories.